@@ -1,28 +1,14 @@
-//#define XERR
+#define XERR
 #include "loop.ih"
 
 // treatmentDeath(): characteristics(LEFT_POST, TUMOR_POST);
 
-extern size_t g_caseIdx;
-extern size_t g_err;
-
 void Loop::characteristics(Status natural, Status tumor)
 {
-//    auto hit =
-//        [&]()
-//        {
-//            return natural == LEFT_POST and tumor == TUMOR_POST and
-//                   g_caseIdx >= g_err;
-//        };
-
-
-//if (hit())xerr("tumor.charact. " << g_caseIdx);
 
                                 // the tumor was self-detected: determine
     d_tumor.characteristics();  // its characteristics
 
-//if (hit())  xerr("treatmentCosts " << g_caseIdx);
-
     d_selfDetected = true;
 
 
@@ -31,12 +17,8 @@ void Loop::characteristics(Status natural, Status tumor)
         // diameterCheck()
     d_caseCost += treatmentCosts(d_tumor.selfDetectAge());
 
-//if (hit()) xerr("setDeathAge " << g_caseIdx);
-
     d_tumor.setDeathAge();
 
-//if (hit()) xerr("setStatus " << g_caseIdx);
-
     if (d_naturalDeathAge < d_tumor.deathAge())     // naturally caused death
         setStatus(natural, d_naturalDeathAge);
     else                                            // or tumor caused death
