@@ -8,19 +8,26 @@ void Loop::maybeDetect(ModBase *modBase, double screeningAge)
     //                   all used
 
     // the check for tumor.diameter() >= 1 is omitted, since
-    // all tumors have at least 1 mm diameter 
+    // all tumors have at least 1 mm diameter
     // (see Marcel: Tue, 30 Jun 2020 10:46:05 +0000)
 
     // modified using Jing Wang's email (Tue, 20 Oct 2020 16:04:42 +0000)
 
-    if (Random::instance().uniform() > sensitivity(modBase))
+    if (
+        double uval = Random::instance().uniform(),
+               sval = sensitivity(modBase);
+        uval > sval
+    )
     {
+        g_log << "    detected FALSE_NEGATIVE (" << uval <<
+                    " > sensitivity (" << sval << ")\n";
+
         ++d_nRoundFN[d_round];
         d_roundInfo[d_round] = FALSE_NEGATIVE;
         return;
     }
                 // Found a tumor during the screening -> no need to call
-                // diameterCheck() 
+                // diameterCheck()
     d_tumor.found();
     ++d_nDetections[d_round];
 
@@ -33,34 +40,40 @@ void Loop::maybeDetect(ModBase *modBase, double screeningAge)
         // if this condition is true then a tumor was found, but the case
         // dies naturally (i.e., not caused by the cancer).
         // Otherwise death is caused by the cancer
-    if (d_naturalDeathAge < d_tumor.deathAge()) 
+    if (d_naturalDeathAge < d_tumor.deathAge())
+    {
+        g_log << "    ** case leaves: natural death\n";
         setStatus(LEFT_DURING, d_naturalDeathAge);
+    }
     else
+    {
+        g_log << "    ** case leaves: tumor death age\n";
         setStatus(TUMOR_DURING, d_tumor.deathAge());
+    }
 }
 
 /////////////////////////////////////////////////////////////////////////
 //     if (betaFunction(modBase->nr()))
 //     {
 //                     // Found a tumor during the screening -> no need to call
-//                     // diameterCheck() 
+//                     // diameterCheck()
 //         d_tumor.detected();
 //         ++d_nDetections[d_round];
-// 
-//         addCost(d_costs.treatment(screeningAge, d_tumor.diameter()));  
+//
+//         addCost(d_costs.treatment(screeningAge, d_tumor.diameter()));
 //         d_tumor.setDeathAge(screeningAge);
-// 
+//
 //         d_roundDetected = d_round;
-// 
+//
 //             // if this condition is true then a tumor was found, but the case
 //             // dies naturally (i.e., not caused by the cancer).
 //             // Otherwise death is caused by the cancer
-//         if (d_naturalDeathAge < d_tumor.deathAge()) 
+//         if (d_naturalDeathAge < d_tumor.deathAge())
 //             setStatus(LEFT_DURING, d_naturalDeathAge);
 //         else
 //             setStatus(TUMOR_DURING, d_tumor.deathAge());
 //     }
-// 
+//
 //     if (d_random.uniform() > sensitivity(modBase))
 //         ++d_nRoundFN[d_round];
-// 
+//
