@@ -7,7 +7,7 @@
 void Loop::preTumorDeath()
 {
     setStatus(LEFT_PRE, d_naturalDeathAge);
-
-    if (d_tumor.selfDetectable())    // would have developed a tumor. Compute the 
-        d_tumor.characteristics(d_deathAge);    // tumor's characteristics
+                                                // would have developed a
+    if (d_tumor.selfDetectable())               // tumor. Compute the tumor's
+        d_tumor.characteristics(d_deathAge);    // characteristics
 }
