@@ -7,11 +7,13 @@ void Loop::screen(double screeningAge)
 {
     // visit all modalities: for (ModBase *...) or comparable
 
+    g_log << "    Loop::screen\n";
+
                                             // org/screen: 4, screen.txt: 1
-    for (ModBase *modBase: d_modalities.use(
-                                d_screening.round(d_round).modalityIndices())
+    for (ModBase *modBase:
+            d_modalities.use(d_screening.round(d_round).modalityIndices())
     )
-    { 
+    {
         if (not use(modBase))
             continue;
                                             // adds the basic costs: screening
@@ -20,14 +22,17 @@ void Loop::screen(double screeningAge)
         addCost(d_costs.screening(screeningAge, modBase->cost()));
 
                                             // determine the tumor
-                                            // characteristics. 
-        if (d_tumor.selfDetectable())                        
-            d_tumor.characteristics(screeningAge); 
+                                            // characteristics.
+        if (d_tumor.selfDetectable())
+            d_tumor.characteristics(screeningAge);
 
                         // test2 (see below)
-        if (d_tumor.selfDetectable() and screeningAge >= d_tumor.detectableAge()) 
+        if (
+            d_tumor.selfDetectable() and
+            screeningAge >= d_tumor.detectableAge()
+        )
             maybeDetect(modBase, screeningAge);
-        else 
+        else
             maybeFalsePositive(modBase, screeningAge);
     }
 }
@@ -37,7 +42,7 @@ void Loop::screen(double screeningAge)
 //   1       0         0           1
 //   0       1         0           1
 //   0       0         0           1
-// 
+//
 // -> calling selfDetectableFalsePositive may not be called when just 'not d_tumor'
 //    is true.
 
@@ -45,7 +50,7 @@ void Loop::screen(double screeningAge)
 
 // Sensitivity (true positive rate) refers to the probability of a positive
 // test, conditioned on truly being positive (so: the power)
-// 
+//
 // Specificity (true negative rate) refers to the probability of a negative
 // test, conditioned on truly being negative. (so: 1 - alpha)
 
@@ -58,4 +63,3 @@ void Loop::screen(double screeningAge)
 //xerr("use " << modBase->id());
 
 //xerr("cpt costs");
-
