@@ -1,15 +1,9 @@
-//#define XERR
+#define XERR
 #include "tumor.ih"
 
-extern size_t g_caseIdx;
-extern size_t g_err;
-
 //  (ORG: calculateSize)
 void Tumor::characteristics(double age)
 {
-    //if (g_caseIdx >= g_err) xerr("AGE: " << age << ",
-    //                                  detectable age: " << d_detectableAge);
-
     check("size");
 
     if ((d_present = (d_detectableAge <= age)))            // there is a tumor
@@ -32,7 +26,4 @@ void Tumor::characteristics(double age)
     }
 
     d_rowCol = d_survival.setVSD(d_diameter);
-
-//if (g_caseIdx >= g_err) xerr(" diameter = " << d_diameter);
-
 }
