@@ -48,3 +48,12 @@ inline bool Tumor::metastasis() const
     return d_survival.metastatis();
 }
 
+inline std::ostream &operator<<(std::ostream &out, Tumor const &tumor)
+{
+    return tumor.insert(out);
+}
+
+inline RowCol const &Tumor::rowCol() const
+{
+    return d_rowCol;
+}
