@@ -81,7 +81,7 @@ class Tumor: public Globals
         double detectableAge() const;                               //  .f
 
         double volume() const;
-        double diameter() const;
+        double diameter() const;                                    // .f
 
         bool metastasis() const;            // only with lung cancer    .f
 
@@ -102,8 +102,6 @@ class Tumor: public Globals
 
         RowCol const &rowCol() const;                               // .f
 
-//        void s4ColIdx();                    // cpt Survival S4 column index
-
     private:
         std::ostream &insert(std::ostream &out) const;
 
